@@ -17,8 +17,8 @@
     Ehms => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
-    GyMMMEd => "E\N{U+1363} MMM d\N{U+1363} y G",
-    GyMMMd => "MMM d\N{U+1363} y G",
+    GyMMMEd => "G y MMM d, E",
+    GyMMMd => "G y MMM d",
     H => "H",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -29,8 +29,7 @@
     MMM => "LLL",
     MMMEd => "E\N{U+1363} MMM d",
     MMMMEd => "E\N{U+1363} MMMM d",
-    "MMMMW-count-one" => "'week' W 'of' MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMM",
+    "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
@@ -51,11 +50,10 @@
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-one" => "'week' w 'of' Y",
     "yw-count-other" => "'week' w 'of' Y",
   },
   code => "am-ET",
-  date_format_full => "EEEE \N{U+1363}d MMMM y",
+  date_format_full => "y MMMM d, EEEE",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "dd/MM/y",
@@ -269,5 +267,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 33,
+  version => 35,
 }
