@@ -28,8 +28,8 @@
     MEd => "dd.MM, E",
     MMM => "LLL",
     MMMEd => "d MMM, E",
-    "MMMMW-count-one" => "MMM, W '\N{U+04bb}\N{U+04d9}\N{U+0444}\N{U+0442}\N{U+04d9}'",
-    "MMMMW-count-other" => "MMM, W '\N{U+04bb}\N{U+04d9}\N{U+0444}\N{U+0442}\N{U+04d9}'",
+    "MMMMW-count-one" => "MMMM, W '\N{U+04bb}\N{U+04d9}\N{U+0444}\N{U+0442}\N{U+04d9}'",
+    "MMMMW-count-other" => "MMMM, W '\N{U+04bb}\N{U+04d9}\N{U+0444}\N{U+0442}\N{U+04d9}'",
     MMMMd => "MMMM d",
     MMMd => "d MMM",
     Md => "dd.MM",
@@ -268,5 +268,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
