@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "prijepodne",
-    "popodne",
+    "AM",
+    "PM",
   ],
   available_formats => {
     Bh => "h B",
@@ -29,9 +29,9 @@
     MMM => "LLL",
     MMMEd => "E, d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-few" => "W. 'sedmica' 'u' MMM",
-    "MMMMW-count-one" => "W. 'sedmica' 'u' MMM",
-    "MMMMW-count-other" => "W. 'sedmica' 'u' MMM",
+    "MMMMW-count-few" => "W. 'sedmica' 'u' MMMM",
+    "MMMMW-count-one" => "W. 'sedmica' 'u' MMMM",
+    "MMMMW-count-other" => "W. 'sedmica' 'u' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMdd => "d. M.",
@@ -54,15 +54,15 @@
     yMd => "d.M.y.",
     yQQQ => "QQQ y.",
     yQQQQ => "QQQQ y.",
-    "yw-count-few" => "w. 'sedmica' 'u' y.",
-    "yw-count-one" => "w. 'sedmica' 'u' y.",
-    "yw-count-other" => "w. 'sedmica' 'u' y.",
+    "yw-count-few" => "w. 'sedmica' 'u' Y.",
+    "yw-count-one" => "w. 'sedmica' 'u' Y.",
+    "yw-count-other" => "w. 'sedmica' 'u' Y.",
   },
   code => "bs",
   date_format_full => "EEEE, d. MMMM y.",
   date_format_long => "d. MMMM y.",
   date_format_medium => "d. MMM y.",
-  date_format_short => "d.M.yy.",
+  date_format_short => "d. M. y.",
   datetime_format_full => "{1} 'u' {0}",
   datetime_format_long => "{1} 'u' {0}",
   datetime_format_medium => "{1} {0}",
@@ -148,7 +148,7 @@
     "maj",
     "jun",
     "jul",
-    "avg",
+    "aug",
     "sep",
     "okt",
     "nov",
@@ -176,7 +176,7 @@
     "maj",
     "juni",
     "juli",
-    "avgust",
+    "august",
     "septembar",
     "oktobar",
     "novembar",
@@ -190,7 +190,7 @@
     "maj",
     "jun",
     "jul",
-    "avg",
+    "aug",
     "sep",
     "okt",
     "nov",
@@ -218,7 +218,7 @@
     "maj",
     "juni",
     "juli",
-    "avgust",
+    "august",
     "septembar",
     "oktobar",
     "novembar",
@@ -273,5 +273,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
