@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "a. m.",
-    "p. m.",
+    "a.\N{U+00a0}m.",
+    "p.\N{U+00a0}m.",
   ],
   available_formats => {
     Bh => "h B",
@@ -274,5 +274,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
