@@ -29,7 +29,7 @@
     MMM => "LLL",
     MMMEd => "E, MMM d",
     "MMMMW-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
-    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMM",
+    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
@@ -130,10 +130,10 @@
   ],
   first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%m/%d/%y",
-  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
+  glibc_date_format => "%m/%d/%Y",
+  glibc_datetime_format => "%a %d %b %Y %r %Z",
   glibc_time_12_format => "%I:%M:%S %p",
-  glibc_time_format => "%H:%M:%S",
+  glibc_time_format => "%r",
   language => "Cherokee",
   month_format_abbreviated => [
     "\N{U+13a4}\N{U+13c3}",
@@ -268,5 +268,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 33,
+  version => 35,
 }
