@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "vorm.",
-    "nachm.",
+    "AM",
+    "PM",
   ],
   available_formats => {
     Bh => "h B",
@@ -29,8 +29,8 @@
     MMM => "LLL",
     MMMEd => "E, d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-one" => "'Woche' W 'im' MMM",
-    "MMMMW-count-other" => "'Woche' W 'im' MMM",
+    "MMMMW-count-one" => "'Woche' W 'im' MMMM",
+    "MMMMW-count-other" => "'Woche' W 'im' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMd => "d.MM.",
@@ -149,7 +149,7 @@
     "Juni",
     "Juli",
     "Aug.",
-    "Sep.",
+    "Sept.",
     "Okt.",
     "Nov.",
     "Dez.",
@@ -273,5 +273,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
