@@ -1,10 +1,15 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM"
+    "am",
+    "pm",
   ],
   available_formats => {
+    Bh => "h B",
+    Bhm => "h:mm B",
+    Bhms => "h:mm:ss B",
     E => "ccc",
+    EBhm => "E, h:mm B",
+    EBhms => "E, h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
@@ -47,8 +52,8 @@
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-one" => "'week' w 'of' y",
-    "yw-count-other" => "'week' w 'of' y"
+    "yw-count-one" => "'week' w 'of' Y",
+    "yw-count-other" => "'week' w 'of' Y",
   },
   code => "en-HK",
   date_format_full => "EEEE, d MMMM y",
@@ -66,7 +71,7 @@
     "Thu",
     "Fri",
     "Sat",
-    "Sun"
+    "Sun",
   ],
   day_format_narrow => [
     "M",
@@ -75,7 +80,7 @@
     "T",
     "F",
     "S",
-    "S"
+    "S",
   ],
   day_format_wide => [
     "Monday",
@@ -84,7 +89,7 @@
     "Thursday",
     "Friday",
     "Saturday",
-    "Sunday"
+    "Sunday",
   ],
   day_stand_alone_abbreviated => [
     "Mon",
@@ -93,7 +98,7 @@
     "Thu",
     "Fri",
     "Sat",
-    "Sun"
+    "Sun",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -102,7 +107,7 @@
     "T",
     "F",
     "S",
-    "S"
+    "S",
   ],
   day_stand_alone_wide => [
     "Monday",
@@ -111,19 +116,19 @@
     "Thursday",
     "Friday",
     "Saturday",
-    "Sunday"
+    "Sunday",
   ],
   era_abbreviated => [
     "BC",
-    "AD"
+    "AD",
   ],
   era_narrow => [
     "B",
-    "A"
+    "A",
   ],
   era_wide => [
     "Before Christ",
-    "Anno Domini"
+    "Anno Domini",
   ],
   first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -144,7 +149,7 @@
     "Sep",
     "Oct",
     "Nov",
-    "Dec"
+    "Dec",
   ],
   month_format_narrow => [
     "J",
@@ -158,7 +163,7 @@
     "S",
     "O",
     "N",
-    "D"
+    "D",
   ],
   month_format_wide => [
     "January",
@@ -172,7 +177,7 @@
     "September",
     "October",
     "November",
-    "December"
+    "December",
   ],
   month_stand_alone_abbreviated => [
     "Jan",
@@ -186,7 +191,7 @@
     "Sep",
     "Oct",
     "Nov",
-    "Dec"
+    "Dec",
   ],
   month_stand_alone_narrow => [
     "J",
@@ -200,7 +205,7 @@
     "S",
     "O",
     "N",
-    "D"
+    "D",
   ],
   month_stand_alone_wide => [
     "January",
@@ -214,7 +219,7 @@
     "September",
     "October",
     "November",
-    "December"
+    "December",
   ],
   name => "English Hong Kong SAR China",
   native_language => "English",
@@ -226,37 +231,37 @@
     "Q1",
     "Q2",
     "Q3",
-    "Q4"
+    "Q4",
   ],
   quarter_format_narrow => [
     1,
     2,
     3,
-    4
+    4,
   ],
   quarter_format_wide => [
     "1st quarter",
     "2nd quarter",
     "3rd quarter",
-    "4th quarter"
+    "4th quarter",
   ],
   quarter_stand_alone_abbreviated => [
     "Q1",
     "Q2",
     "Q3",
-    "Q4"
+    "Q4",
   ],
   quarter_stand_alone_narrow => [
     1,
     2,
     3,
-    4
+    4,
   ],
   quarter_stand_alone_wide => [
     "1st quarter",
     "2nd quarter",
     "3rd quarter",
-    "4th quarter"
+    "4th quarter",
   ],
   script => undef,
   territory => "Hong Kong SAR China",
@@ -265,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 31
+  version => 35,
 }
