@@ -1,15 +1,15 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM",
+    "am",
+    "pm",
   ],
   available_formats => {
     Bh => "h B",
     Bhm => "h:mm B",
     Bhms => "h:mm:ss B",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E, h:mm B",
+    EBhms => "E, h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
@@ -269,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
