@@ -29,7 +29,7 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-other" => "'minggu' 'ke'-W MMM",
+    "MMMMW-count-other" => "'minggu' 'ke'-W MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d/M",
@@ -142,7 +142,7 @@
     "Mei",
     "Jun",
     "Jul",
-    "Agt",
+    "Agu",
     "Sep",
     "Okt",
     "Nov",
@@ -184,7 +184,7 @@
     "Mei",
     "Jun",
     "Jul",
-    "Agt",
+    "Agu",
     "Sep",
     "Okt",
     "Nov",
@@ -267,5 +267,5 @@
   time_format_medium => "HH.mm.ss",
   time_format_short => "HH.mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
