@@ -28,8 +28,8 @@
     MEd => "dd.MM, E",
     MMM => "LLL",
     MMMEd => "d MMM, E",
-    "MMMMW-count-one" => "MMM '\N{U+0430}\N{U+0439}\N{U+044b}\N{U+043d}\N{U+044b}\N{U+04a3}' W-'\N{U+0430}\N{U+043f}\N{U+0442}\N{U+0430}\N{U+0441}\N{U+044b}'",
-    "MMMMW-count-other" => "MMM '\N{U+0430}\N{U+0439}\N{U+044b}\N{U+043d}\N{U+044b}\N{U+04a3}' W-'\N{U+0430}\N{U+043f}\N{U+0442}\N{U+0430}\N{U+0441}\N{U+044b}'",
+    "MMMMW-count-one" => "MMMM '\N{U+0430}\N{U+0439}\N{U+044b}\N{U+043d}\N{U+044b}\N{U+04a3}' W-'\N{U+0430}\N{U+043f}\N{U+0442}\N{U+0430}\N{U+0441}\N{U+044b}'",
+    "MMMMW-count-other" => "MMMM '\N{U+0430}\N{U+0439}\N{U+044b}\N{U+043d}\N{U+044b}\N{U+04a3}' W-'\N{U+0430}\N{U+043f}\N{U+0442}\N{U+0430}\N{U+0441}\N{U+044b}'",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "dd.MM",
@@ -63,13 +63,13 @@
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
-    "\N{U+0414}\N{U+0441}",
-    "\N{U+0421}\N{U+0441}",
-    "\N{U+0421}\N{U+0440}",
-    "\N{U+0411}\N{U+0441}",
-    "\N{U+0416}\N{U+043c}",
-    "\N{U+0421}\N{U+0431}",
-    "\N{U+0416}\N{U+0441}",
+    "\N{U+0434}\N{U+0441}",
+    "\N{U+0441}\N{U+0441}",
+    "\N{U+0441}\N{U+0440}",
+    "\N{U+0431}\N{U+0441}",
+    "\N{U+0436}\N{U+043c}",
+    "\N{U+0441}\N{U+0431}",
+    "\N{U+0436}\N{U+0441}",
   ],
   day_format_narrow => [
     "\N{U+0414}",
@@ -90,13 +90,13 @@
     "\N{U+0436}\N{U+0435}\N{U+043a}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
   ],
   day_stand_alone_abbreviated => [
-    "\N{U+0414}\N{U+0441}",
-    "\N{U+0421}\N{U+0441}",
-    "\N{U+0421}\N{U+0440}",
-    "\N{U+0411}\N{U+0441}",
-    "\N{U+0416}\N{U+043c}",
-    "\N{U+0421}\N{U+0431}",
-    "\N{U+0416}\N{U+0441}",
+    "\N{U+0434}\N{U+0441}",
+    "\N{U+0441}\N{U+0441}",
+    "\N{U+0441}\N{U+0440}",
+    "\N{U+0431}\N{U+0441}",
+    "\N{U+0436}\N{U+043c}",
+    "\N{U+0441}\N{U+0431}",
+    "\N{U+0436}\N{U+0441}",
   ],
   day_stand_alone_narrow => [
     "\N{U+0414}",
@@ -108,13 +108,13 @@
     "\N{U+0416}",
   ],
   day_stand_alone_wide => [
-    "\N{U+0414}\N{U+04af}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
-    "\N{U+0421}\N{U+0435}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
-    "\N{U+0421}\N{U+04d9}\N{U+0440}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
-    "\N{U+0411}\N{U+0435}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
-    "\N{U+0416}\N{U+04b1}\N{U+043c}\N{U+0430}",
-    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
-    "\N{U+0416}\N{U+0435}\N{U+043a}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0434}\N{U+04af}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0441}\N{U+0435}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0441}\N{U+04d9}\N{U+0440}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0431}\N{U+0435}\N{U+0439}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0436}\N{U+04b1}\N{U+043c}\N{U+0430}",
+    "\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
+    "\N{U+0436}\N{U+0435}\N{U+043a}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+0431}\N{U+0456}",
   ],
   era_abbreviated => [
     "\N{U+0431}.\N{U+0437}.\N{U+0434}.",
@@ -178,18 +178,18 @@
     "\N{U+0436}\N{U+0435}\N{U+043b}\N{U+0442}\N{U+043e}\N{U+049b}\N{U+0441}\N{U+0430}\N{U+043d}",
   ],
   month_stand_alone_abbreviated => [
-    "\N{U+049a}\N{U+0430}\N{U+04a3}.",
-    "\N{U+0410}\N{U+049b}\N{U+043f}.",
-    "\N{U+041d}\N{U+0430}\N{U+0443}.",
-    "\N{U+0421}\N{U+04d9}\N{U+0443}.",
-    "\N{U+041c}\N{U+0430}\N{U+043c}.",
-    "\N{U+041c}\N{U+0430}\N{U+0443}.",
-    "\N{U+0428}\N{U+0456}\N{U+043b}.",
-    "\N{U+0422}\N{U+0430}\N{U+043c}.",
-    "\N{U+049a}\N{U+044b}\N{U+0440}.",
-    "\N{U+049a}\N{U+0430}\N{U+0437}.",
-    "\N{U+049a}\N{U+0430}\N{U+0440}.",
-    "\N{U+0416}\N{U+0435}\N{U+043b}.",
+    "\N{U+049b}\N{U+0430}\N{U+04a3}.",
+    "\N{U+0430}\N{U+049b}\N{U+043f}.",
+    "\N{U+043d}\N{U+0430}\N{U+0443}.",
+    "\N{U+0441}\N{U+04d9}\N{U+0443}.",
+    "\N{U+043c}\N{U+0430}\N{U+043c}.",
+    "\N{U+043c}\N{U+0430}\N{U+0443}.",
+    "\N{U+0448}\N{U+0456}\N{U+043b}.",
+    "\N{U+0442}\N{U+0430}\N{U+043c}.",
+    "\N{U+049b}\N{U+044b}\N{U+0440}.",
+    "\N{U+049b}\N{U+0430}\N{U+0437}.",
+    "\N{U+049b}\N{U+0430}\N{U+0440}.",
+    "\N{U+0436}\N{U+0435}\N{U+043b}.",
   ],
   month_stand_alone_narrow => [
     "\N{U+049a}",
@@ -268,5 +268,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
