@@ -28,7 +28,6 @@
     MEd => "d/M, E",
     MMM => "LLL",
     MMMEd => "E, d MMM",
-    "MMMMW-count-one" => "'week' W 'of' MMM",
     "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "d MMMM",
     MMMd => "MMM d",
@@ -52,8 +51,7 @@
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-one" => "'week' w 'of' y",
-    "yw-count-other" => "'week' w 'of' y",
+    "yw-count-other" => "'week' w 'of' Y",
   },
   code => "kn-IN",
   date_format_full => "EEEE, MMMM d, y",
@@ -270,5 +268,5 @@
   time_format_medium => "hh:mm:ss a",
   time_format_short => "hh:mm a",
   variant => undef,
-  version => 33,
+  version => 35,
 }
