@@ -28,7 +28,7 @@
     MEd => "E, d-M",
     MMM => "LLL",
     MMMEd => "E, d MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMM",
+    "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd/MM",
@@ -267,5 +267,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 32,
+  version => 35,
 }
