@@ -28,7 +28,10 @@
     MEd => "E, M-d",
     MMM => "LLL",
     MMMEd => "E, d 'ta'\N{U+2019} MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-few" => "W '\N{U+0121}img\N{U+0127}a' 'ta''' MMMM",
+    "MMMMW-count-many" => "W '\N{U+0121}img\N{U+0127}a' 'ta''' MMMM",
+    "MMMMW-count-one" => "W '\N{U+0121}img\N{U+0127}a' 'ta''' MMMM",
+    "MMMMW-count-other" => "W '\N{U+0121}img\N{U+0127}a' 'ta''' MMMM",
     MMMMd => "d 'ta'\N{U+2019} MMMM",
     MMMd => "MMM d",
     Md => "MM-dd",
@@ -46,10 +49,13 @@
     yMMMEd => "E, d 'ta'\N{U+2019} MMM, y",
     yMMMM => "MMMM y",
     yMMMd => "d 'ta'\N{U+2019} MMM, y",
-    yMd => "y-MM-dd",
+    yMd => "M/d/y",
     yQQQ => "QQQ - y",
     yQQQQ => "QQQQ - y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-few" => "w '\N{U+0121}img\N{U+0127}a' 'ta''' Y",
+    "yw-count-many" => "w '\N{U+0121}img\N{U+0127}a' 'ta''' Y",
+    "yw-count-one" => "w '\N{U+0121}img\N{U+0127}a' 'ta''' Y",
+    "yw-count-other" => "w '\N{U+0121}img\N{U+0127}a' 'ta''' Y",
   },
   code => "mt",
   date_format_full => "EEEE, d 'ta'\N{U+2019} MMMM y",
@@ -266,5 +272,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
