@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "am",
-    "pm",
+    "AM",
+    "PM",
   ],
   available_formats => {
     Bh => "h B",
@@ -270,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 32,
+  version => 35,
 }
