@@ -28,8 +28,8 @@
     MEd => "MM-dd, E",
     MMM => "LLL",
     MMMEd => "MMM d, E",
-    "MMMMW-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMM",
-    "MMMMW-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMM",
+    "MMMMW-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMMM",
+    "MMMMW-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "MM-dd",
@@ -130,9 +130,9 @@
   ],
   first_day_of_week => 6,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%m/%d/%y",
-  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
-  glibc_time_12_format => "%I:%M:%S %p",
+  glibc_date_format => "\N{U+062f} %Y \N{U+062f} %B %e",
+  glibc_datetime_format => "%A \N{U+062f} %Y \N{U+062f} %B %e\N{U+060c} %Z %H:%M:%S",
+  glibc_time_12_format => "\N{U+202b}%I:%M:%S %p\N{U+202c}",
   glibc_time_format => "%H:%M:%S",
   language => "Pashto",
   month_format_abbreviated => [
@@ -268,5 +268,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
