@@ -29,8 +29,8 @@
     MMM => "LLL",
     MMMEd => "E, d/MM",
     MMMMEd => "ccc, d 'de' MMMM",
-    "MMMMW-count-one" => "W.'\N{U+00aa}' 'semana' 'de' MMM",
-    "MMMMW-count-other" => "W.'\N{U+00aa}' 'semana' 'de' MMM",
+    "MMMMW-count-one" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
+    "MMMMW-count-other" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
     MMMMd => "d 'de' MMMM",
     MMMd => "d/MM",
     MMdd => "dd/MM",
@@ -134,7 +134,7 @@
     "antes de Cristo",
     "depois de Cristo",
   ],
-  first_day_of_week => 1,
+  first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
   glibc_date_format => "%d-%m-%Y",
   glibc_datetime_format => "%a %d %b %Y %T %Z",
@@ -274,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
