@@ -19,11 +19,11 @@
     GyMMM => "LLL y G",
     GyMMMEd => "E, d MMM y '\N{U+0433}'. G",
     GyMMMd => "d MMM y '\N{U+0433}'. G",
-    H => "H",
-    Hm => "H:mm",
-    Hms => "H:mm:ss",
-    Hmsv => "H:mm:ss v",
-    Hmv => "H:mm v",
+    H => "HH",
+    Hm => "HH:mm",
+    Hms => "HH:mm:ss",
+    Hmsv => "HH:mm:ss v",
+    Hmv => "HH:mm v",
     M => "L",
     MEd => "E, dd.MM",
     MMM => "LLL",
@@ -269,10 +269,10 @@
   ],
   script => undef,
   territory => "Kazakhstan",
-  time_format_full => "H:mm:ss zzzz",
-  time_format_long => "H:mm:ss z",
-  time_format_medium => "H:mm:ss",
-  time_format_short => "H:mm",
+  time_format_full => "HH:mm:ss zzzz",
+  time_format_long => "HH:mm:ss z",
+  time_format_medium => "HH:mm:ss",
+  time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
