@@ -29,10 +29,10 @@
     MEd => "E, d. M.",
     MMM => "LLL",
     MMMEd => "E, d. MMM",
-    "MMMMW-count-few" => "W. 'teden' 'v' MMM",
-    "MMMMW-count-one" => "W. 'teden' 'v' MMM",
-    "MMMMW-count-other" => "W. 'teden' 'v' MMM",
-    "MMMMW-count-two" => "W. 'teden' 'v' MMM",
+    "MMMMW-count-few" => "W. 'teden' 'v' MMMM",
+    "MMMMW-count-one" => "W. 'teden' 'v' MMMM",
+    "MMMMW-count-other" => "W. 'teden' 'v' MMMM",
+    "MMMMW-count-two" => "W. 'teden' 'v' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     Md => "d. M.",
@@ -273,5 +273,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
