@@ -1,10 +1,15 @@
 {
   am_pm_abbreviated => [
     "AM",
-    "PM"
+    "PM",
   ],
   available_formats => {
+    Bh => "h B",
+    Bhm => "h:mm B",
+    Bhms => "h:mm:ss B",
     E => "ccc",
+    EBhm => "E h:mm B",
+    EBhms => "E h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d, E",
@@ -24,8 +29,7 @@
     MMM => "LLL",
     MMMEd => "MMM d, E",
     MMMMEd => "E, MMMM d",
-    "MMMMW-count-one" => "'week' W 'of' MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMM",
+    "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "MM-dd",
@@ -46,8 +50,7 @@
     yMd => "y-MM-dd",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
-    "yw-count-one" => "'week' w 'of' y",
-    "yw-count-other" => "'week' w 'of' y"
+    "yw-count-other" => "'week' w 'of' Y",
   },
   code => "sn-ZW",
   date_format_full => "y MMMM d, EEEE",
@@ -65,7 +68,7 @@
     "Chn",
     "Chs",
     "Mug",
-    "Svo"
+    "Svo",
   ],
   day_format_narrow => [
     "M",
@@ -74,7 +77,7 @@
     "C",
     "C",
     "M",
-    "S"
+    "S",
   ],
   day_format_wide => [
     "Muvhuro",
@@ -83,7 +86,7 @@
     "China",
     "Chishanu",
     "Mugovera",
-    "Svondo"
+    "Svondo",
   ],
   day_stand_alone_abbreviated => [
     "Muv",
@@ -92,7 +95,7 @@
     "Chn",
     "Chs",
     "Mug",
-    "Svo"
+    "Svo",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -101,7 +104,7 @@
     "C",
     "C",
     "M",
-    "S"
+    "S",
   ],
   day_stand_alone_wide => [
     "Muvhuro",
@@ -110,19 +113,19 @@
     "China",
     "Chishanu",
     "Mugovera",
-    "Svondo"
+    "Svondo",
   ],
   era_abbreviated => [
     "BC",
-    "AD"
+    "AD",
   ],
   era_narrow => [
     "BC",
-    "AD"
+    "AD",
   ],
   era_wide => [
     "Kristo asati auya",
-    "mugore ramambo vedu"
+    "mugore ramambo vedu",
   ],
   first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -143,7 +146,7 @@
     "Gun",
     "Gum",
     "Mbu",
-    "Zvi"
+    "Zvi",
   ],
   month_format_narrow => [
     "N",
@@ -157,7 +160,7 @@
     "G",
     "G",
     "M",
-    "Z"
+    "Z",
   ],
   month_format_wide => [
     "Ndira",
@@ -171,7 +174,7 @@
     "Gunyana",
     "Gumiguru",
     "Mbudzi",
-    "Zvita"
+    "Zvita",
   ],
   month_stand_alone_abbreviated => [
     "Ndi",
@@ -185,7 +188,7 @@
     "Gun",
     "Gum",
     "Mbu",
-    "Zvi"
+    "Zvi",
   ],
   month_stand_alone_narrow => [
     "N",
@@ -199,7 +202,7 @@
     "G",
     "G",
     "M",
-    "Z"
+    "Z",
   ],
   month_stand_alone_wide => [
     "Ndira",
@@ -213,7 +216,7 @@
     "Gunyana",
     "Gumiguru",
     "Mbudzi",
-    "Zvita"
+    "Zvita",
   ],
   name => "Shona Zimbabwe",
   native_language => "chiShona",
@@ -225,37 +228,37 @@
     "K1",
     "K2",
     "K3",
-    "K4"
+    "K4",
   ],
   quarter_format_narrow => [
     1,
     2,
     3,
-    4
+    4,
   ],
   quarter_format_wide => [
     "Kota 1",
     "Kota 2",
     "Kota 3",
-    "Kota 4"
+    "Kota 4",
   ],
   quarter_stand_alone_abbreviated => [
     "K1",
     "K2",
     "K3",
-    "K4"
+    "K4",
   ],
   quarter_stand_alone_narrow => [
     1,
     2,
     3,
-    4
+    4,
   ],
   quarter_stand_alone_wide => [
     "Kota 1",
     "Kota 2",
     "Kota 3",
-    "Kota 4"
+    "Kota 4",
   ],
   script => undef,
   territory => "Zimbabwe",
@@ -264,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 31
+  version => 35,
 }
