@@ -29,9 +29,9 @@
     MMM => "LLL",
     MMMEd => "E d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-few" => "W. 'sedmica' 'u' MMM.",
-    "MMMMW-count-one" => "W. 'sedmica' 'u' MMM.",
-    "MMMMW-count-other" => "W. 'sedmica' 'u' MMM.",
+    "MMMMW-count-few" => "W. 'sedmica' 'u' MMMM.",
+    "MMMMW-count-one" => "W. 'sedmica' 'u' MMMM.",
+    "MMMMW-count-other" => "W. 'sedmica' 'u' MMMM.",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMMdd => "dd.MMM",
@@ -275,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
