@@ -28,8 +28,8 @@
     MEd => "dd-MM, E",
     MMM => "LLL",
     MMMEd => "MMM d, E",
-    "MMMMW-count-one" => "MMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
-    "MMMMW-count-other" => "MMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
+    "MMMMW-count-one" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
+    "MMMMW-count-other" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
     MMMMd => "d MMMM",
     MMMd => "MMM d",
     MMdd => "dd-MM",
@@ -132,10 +132,10 @@
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%m/%d/%y",
-  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
-  glibc_time_12_format => "%I:%M:%S %p",
-  glibc_time_format => "%H:%M:%S",
+  glibc_date_format => "%A %d %B %Y",
+  glibc_datetime_format => "%A %d %B %Y %I:%M:%S %p %Z",
+  glibc_time_12_format => "%I:%M:%S %p %Z",
+  glibc_time_format => "%I:%M:%S  %Z",
   language => "Tamil",
   month_format_abbreviated => [
     "\N{U+0b9c}\N{U+0ba9}.",
@@ -270,5 +270,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 35,
 }
